==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtchgstrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "replacement of strings by the specified condition"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "a list of numerical attributes"
#define FLDC "a list of numerical attributes you want to replace"
#define FLDF NULL

/*-c*/
#define REPT "list of replacement condition"
#define REPC "a list of replacement condition (target character string x: character string which x is replaced with)"

/*-O*/
#define OTHT "character string used for those not satisfying the condition by -c"
#define OTHC "Specify  character string which replaces the value which does not  satisfy the condition by -c. If -O is used, that value is replaced by null  value."

/*-F*/
#define FRPT "no replacement is made for those not satisfying the condition by -c"
#define FRPC "Leave the attribute value as the original one, if the replacement  condition is not satisfied"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command replaces the attribute specified by -f  with a character string which  is given by replacement condition with -c."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xtchgstr -f classification code -c 015:bread,101:milk -i dat.xt -o rsl.xt\n\
  xtchgstr -f classification code -c 015:bread,101:milk -O undefind -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-2.0.1.tar.gz: musashi-core-2.0.1/help/en/xtchgstrHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "replacement of strings by the specified condition"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "a list of numerical attributes"
#define FLDC "a list of numerical attributes you want to replace"
#define FLDF NULL

/*-c*/
#define REPT "list of replacement condition"
#define REPC "a list of replacement condition (target character string x: character string which x is replaced with)"

/*-O*/
#define OTHT "character string used for those not satisfying the condition by -c"
#define OTHC "Specify  character string which replaces the value which does not  satisfy the condition by -c. If -O is used, that value is replaced by null  value."

/*-F*/
#define FRPT "no replacement is made for those not satisfying the condition by -c"
#define FRPC "Leave the attribute value as the original one, if the replacement  condition is not satisfied"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "xtchgstr replaces the character string in the attribute -f with a character string defined in the condition -c. Instead of replacing the string in place, the newly defined character string can be stored as a new attribute when the option -A is specified. Replacement condition is defined by pairs of character string and target character string to be replaced with. Example: -c'BrandA:A,BrandB:B' BrandA is replaced by A and BrandB is replaced by B. When the character string does not match with the condition defined in -c, it will be replaced by a null character (*) . You may replace null values by other characters with the option -O. If the attribute value does not match the replacement condition, you can use the option -F to leave it as the original value. Note that option -O and -F cannot be used at the same time. This command does not support partial match. Alternatively, xtsed can be used for replacing characters with partial match. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  xtchgstr -f classification code -c 015:bread,101:milk -i dat.xt -o rsl.xt\n\
  xtchgstr -f classification code -c 015:bread,101:milk -O undefind -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
